@@ -1,10 +1,6 @@
 # Built in Modules
 import importlib
-import itertools
 import sys
-# Local package imports
-
-# from . import profilers
 
 
 class Script:
@@ -210,6 +206,27 @@ class Script:
             else:
                 exit(f"Multiple at execution profilers were defined. Failed when adding profiler {profiler}")
 
+    def run_work(self, profilefile, bash_options=['']):
+        """
+        run_work_profiling writes into the profile bash script the call to run the user defined bash script. This is
+        used when no profiler needs to execute the user defined bash script.
+
+        Parameters
+        ----------
+        profilefile: io.TextIOWrapper
+            open profile file with write permissions.
+        bash_options: list
+            List of bash options to pass to the user defined bash script.
+
+        Returns
+        -------
+
+        """
+        profilefile.write('bash {} {}\n'.format(self.tmp_work_script,
+                                                ' '.join(str(x) for x in bash_options)))
+        profilefile.write('\n')
+        return
+
     def end_profiling(self, profiler, profilefile):
         """
         end_profiling is used to call the define_end() function of the different profilers.
@@ -828,7 +845,6 @@ class Script:
                 workfile.write(line)
         return
 
-
     def add_options(self, profilefile):
         """
         add_options adds the queue options from the Script object to the profile file.
@@ -887,6 +903,7 @@ class Script:
             profilefile.write('  mkdir ${WORKING_DIR}\n')
             profilefile.write('fi\n')
             profilefile.write('cd ${WORKING_DIR}\n')
+            profilefile.write(f'export PYTHON_INSTANCE={sys.executable}')
             profilefile.write('\n')
             if self.profiling is not None:
                 for key in self.profiling.keys():
@@ -903,9 +920,3 @@ class Script:
             else:
                 self.run_work(profilefile, bash_options)
         return
-
-    def run_work(self, profilefile, bash_options=['']):
-        profilefile.write('bash {} {}\n'.format(self.tmp_work_script,
-                                                ' '.join(str(x) for x in bash_options)))
-        profilefile.write('\n')
-        return
